@@ -107,8 +107,8 @@ sub type {
     # default is cpan module or distribution
     $$source =~ s/^cpan:(?!:\w+)//i;
 
-    return if $$source =~ /:/ && $$source !~ /::/;
-
+    # in case typos like IO:File
+    $$source =~ s/(?<!:):(?!:)/::/g;
 
     # if it's not a distribution name like
     # 'S/SU/SUNNAVY/IP-QQWry-v0.0.15.tar.gz', convert '-' to '::'.
@@ -138,7 +138,7 @@ sunnavy  C<< <sunnavy@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Shipwright is Copyright 2007-2012 Best Practical Solutions, LLC.
+Shipwright is Copyright 2007-2015 Best Practical Solutions, LLC.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
