@@ -93,6 +93,10 @@ sub run {
         $compressed->run(@_);
     }
     elsif ( !$result &&  $self->source =~ /\S/ ) {
+        if ( Module::CoreList->is_core( $self->source )) {
+            $self->log->info("skipping dual lifed " . $self->source . " because can't find it on cpan any more");
+            return;
+        }
         my $error = q{invalid source: can't find '} . $self->source . q{'};
         if ( $self->version ) {
             $error .= ' version ' . $self->version;
@@ -203,7 +207,7 @@ sunnavy  C<< <sunnavy@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Shipwright is Copyright 2007-2012 Best Practical Solutions, LLC.
+Shipwright is Copyright 2007-2015 Best Practical Solutions, LLC.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
